@@ -1,25 +1,10 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     He MingYang <hemingyang@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "dbusscreenshotservice.h"
+#include "utils/eventlogutils.h"
 
 #include <QtCore/QMetaObject>
 #include <QtCore/QByteArray>
@@ -55,7 +40,15 @@ void DBusScreenshotService::setSingleInstance(bool instance)
 
 void DBusScreenshotService::StartScreenshot()
 {
-    qDebug() << "DBus screenshot service! start screenshot";
+    qDebug() << "DBus screenshot service! screenshot";
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B6"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->startScreenshot();
     m_singleInstance = true;
@@ -65,6 +58,15 @@ void DBusScreenshotService::DelayScreenshot(qlonglong in0)
 {
     qDebug() << "DBus screenshot service! delay screenshot";
     // handle method call com.deepin.Screenshot.DelayScreenshot
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B2"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->delayScreenshot(in0);
     m_singleInstance = true;
@@ -83,6 +85,15 @@ void DBusScreenshotService::OcrScreenshot()
 {
     qDebug() << "DBus screenshot service! OcrScreenshot";
     // handle method call com.deepin.Screenshot.NoNotify
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B4"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->OcrScreenshot();
     m_singleInstance = true;
@@ -92,6 +103,15 @@ void DBusScreenshotService::ScrollScreenshot()
 {
     qDebug() << "DBus screenshot service! ScrollScreenshot";
     // handle method call com.deepin.Screenshot.NoNotify
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B5"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->ScrollScreenshot();
     m_singleInstance = true;
@@ -101,6 +121,15 @@ void DBusScreenshotService::TopWindowScreenshot()
 {
     qDebug() << "DBus screenshot service! topWindow screenshot";
     // handle method call com.deepin.Screenshot.TopWindow
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B3"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->topWindowScreenshot();
     m_singleInstance = true;
@@ -110,6 +139,15 @@ void DBusScreenshotService::FullscreenScreenshot()
 {
     qDebug() << "DBus screenshot service! Fullscreen screenshot";
     // handle method call com.deepin.Screenshot.Fullscreenshot
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::Start},
+        {"version", QCoreApplication::applicationVersion()},
+        {"mode", 1},
+        {"startup_mode", "B1"}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (!m_singleInstance)
         parent()->fullscreenScreenshot();
     m_singleInstance = true;
