@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "timewidget.h"
 #include "dde-dock/constants.h"
@@ -62,6 +46,9 @@ TimeWidget::TimeWidget(DWidget *parent):
     m_lightIcon = new QIcon(":/res/light.svg");
     m_shadeIcon = new QIcon(":/res/shade.svg");
     m_currentIcon = m_lightIcon;
+    //this->setAttribute(Qt::WA_StyledBackground,true);
+    //this->setStyleSheet("background-color: rgb(255,255, 0)");
+    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Minimum);
 }
 
 TimeWidget::~TimeWidget()
@@ -94,14 +81,14 @@ QSize TimeWidget::sizeHint() const
     QFontMetrics fm(RECORDER_TIME_FONT);
     int width = -1;
     int height = -1;
-    if (0 == m_position || 2 == m_position) {
-        width = fm.boundingRect(RECORDER_TIME_LEVEL_SIZE).size().width();
+    if (position::top == m_position || position::bottom == m_position) {
+        width = fm.boundingRect(RECORDER_TIME_LEVEL_SIZE).size().width() + 5 + RECORDER_TIME_LEVEL_ICON_SIZE + RECORDER_TEXT_TOP_BOTTOM_X;
         height = RECORDER_TIME_LEVEL_ICON_SIZE;
-    } else if (1 == m_position || 3 == m_position) {
-        width = fm.boundingRect(RECORDER_TIME_VERTICAL_SIZE).size().width();
+    } else if (position::left == m_position || position::right == m_position) {
+        width = RECORDER_TIME_LEVEL_ICON_SIZE + RECORDER_TEXT_TOP_BOTTOM_X;
         height = RECORDER_TIME_VERTICAL_ICON_SIZE;
     }
-    return QSize(width, height);
+    return QSize(width, this->geometry().height());
 }
 
 void TimeWidget::onTimeout()
@@ -164,10 +151,14 @@ void TimeWidget::paintEvent(QPaintEvent *e)
             path.addRoundedRect(rc, radius, radius);
 
         } else if (position::right == m_position || position::left == m_position) {
-            int minSize = std::min(width(), height());
-            QRect rc(0, 0, minSize, minSize);
-            rc.moveTo(rect().center() - rc.center());
-            path.addRoundedRect(rc, radius, radius);
+            if (rect().width() > RECORDER_TIME_LEVEL_ICON_SIZE) {
+                int minSize = std::min(width(), height());
+                QRect rc(0, 0, minSize, minSize);
+                rc.moveTo(rect().center() - rc.center());
+                path.addRoundedRect(rc, radius, radius);
+            } else {
+                painter.setPen(Qt::black);
+            }
         }
         painter.fillPath(path, color);
     } else {
@@ -176,21 +167,24 @@ void TimeWidget::paintEvent(QPaintEvent *e)
     painter.setOpacity(1);
     painter.setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform, true);
     const auto ratio = devicePixelRatioF();
+    //判断任务栏在屏幕上的位置,上下左右
     if (position::top == m_position || position::bottom == m_position) {
-        m_pixmap = QIcon::fromTheme(QString("recordertime"), *m_currentIcon).pixmap(QSize(RECORDER_TIME_LEVEL_ICON_SIZE, RECORDER_TIME_LEVEL_ICON_SIZE) * ratio);
-        m_pixmap.setDevicePixelRatio(ratio);
+        m_pixmap = QIcon::fromTheme(QString("recordertime"), *m_currentIcon).pixmap(QSize(RECORDER_TIME_LEVEL_ICON_SIZE, RECORDER_TIME_LEVEL_ICON_SIZE));
+        //m_pixmap.setDevicePixelRatio(ratio);
         const QRectF &rf = QRectF(rect());
         const QRectF &prf = QRectF(m_pixmap.rect());
-        QPointF pf = rf.center() - prf.center() / m_pixmap.devicePixelRatioF();
-        painter.drawPixmap(RECORDER_ICON_TOP_BOTTOM_X, static_cast<int>(pf.y()), m_pixmap);
+        QPointF pf = rf.center() - prf.center();
+        //绘制录像小图标
+        painter.drawPixmap(5, static_cast<int>(pf.y() + 1), m_pixmap);
         QFont font = RECORDER_TIME_FONT;
         painter.setFont(font);
         QFontMetrics fm(font);
 //        painter.drawText(m_pixmap.width() * static_cast<int>(ratio) + RECORDER_TEXT_TOP_BOTTOM_X + RECORDER_ICON_TOP_BOTTOM_X, rect().y(), rect().width(), rect().height(), Qt::AlignLeft | Qt::AlignVCenter, m_showTimeStr);
-        int tx = static_cast<int>(m_pixmap.width()  / ratio) + RECORDER_TEXT_TOP_BOTTOM_X + RECORDER_ICON_TOP_BOTTOM_X;
+        int tx = static_cast<int>(m_pixmap.width()) + RECORDER_TEXT_TOP_BOTTOM_X;
         int ty = rect().y();
         int twidth = rect().width();
         int theight = rect().height();
+        //绘制时间
         painter.drawText(tx, ty, twidth, theight, Qt::AlignLeft | Qt::AlignVCenter, m_showTimeStr);
     } else if (position::right == m_position || position::left == m_position) {
         m_pixmap = QIcon::fromTheme(QString("recordertime"), *m_currentIcon).pixmap(QSize(RECORDER_TIME_VERTICAL_ICON_SIZE, RECORDER_TIME_VERTICAL_ICON_SIZE) * ratio);
