@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "event_monitor.h"
 #include "keydefine.h"
@@ -44,10 +28,15 @@ EventMonitor::~EventMonitor()
 void EventMonitor::releaseRes()
 {
     if (m_display_datalink && m_display) {
+        qInfo() << __FUNCTION__ << __LINE__ << "执行 XRecordDisableContext ...";
         XRecordDisableContext(m_display, m_context);
+        qInfo() << __FUNCTION__ << __LINE__ << "执行 XRecordFreeContext ...";
         XRecordFreeContext(m_display, m_context);
+        qInfo() << __FUNCTION__ << __LINE__ << "执行 XSync ...";
         XSync(m_display, False);
+        qInfo() << __FUNCTION__ << __LINE__ << "执行 XCloseDisplay m_display_datalink...";
         XCloseDisplay(m_display_datalink);
+        qInfo() << __FUNCTION__ << __LINE__ << "执行 XCloseDisplay m_display...";
         XCloseDisplay(m_display);
         m_display_datalink = nullptr;
         m_display = nullptr;
