@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
@@ -41,6 +25,7 @@
 #include "utils/saveutils.h"
 #include "utils/voicevolumewatcher.h"
 #include "utils/camerawatcher.h"
+#include "camera/devnummonitor.h"
 #include "utils/screengrabber.h"
 #include "dbusinterface/dbuscontrolcenter.h"
 #include "dbusinterface/dbusnotify.h"
@@ -50,6 +35,7 @@
 #include "recordertablet.h"
 #include "dbusinterface/ocrinterface.h"
 #include "dbusinterface/pinscreenshotsinterface.h"
+#include "utils/delaytime.h"
 
 #include <DWindowManagerHelper>
 #include <DDialog>
@@ -142,6 +128,7 @@ public:
     explicit MainWindow(DWidget *parent = nullptr);
     ~MainWindow()
     {
+        qInfo() << __FUNCTION__ << __LINE__ << "正在释放截图录屏相关资源...";
         if (m_pVoiceVolumeWatcher) {
             m_pVoiceVolumeWatcher->setWatch(false);
             // 之前run函数里面有sleep,所以此处加terminate，现在采用定时器检测摄像头，就不考虑各个平台下线程退出的方式
@@ -154,13 +141,10 @@ public:
             delete m_pCameraWatcher;
             m_pCameraWatcher = nullptr;
         }
-
-        if (m_pScreenCaptureEvent) {
-            m_pScreenCaptureEvent->releaseRes();
-            //m_pScreenCaptureEvent->terminate();
-            m_pScreenCaptureEvent->wait();
-            delete m_pScreenCaptureEvent;
-            m_pScreenCaptureEvent = nullptr;
+        if (m_devnumMonitor) {
+            m_devnumMonitor->setWatch(false);
+            delete m_devnumMonitor;
+            m_devnumMonitor = nullptr;
         }
 #ifdef KF5_WAYLAND_FLAGE_ON
         if (Utils::isWaylandMode && m_connectionThread) {
@@ -244,9 +228,31 @@ public:
             delete m_keyButtonList.at(i);
         }
         m_keyButtonList.clear();
-
+        if (m_pScreenCaptureEvent) {
+            qInfo() << __FUNCTION__ << __LINE__ << "正在退出截图录屏全局事件监听线程...";
+            DelayTime *delayTime = new DelayTime(3000);
+            delayTime->setForceToExitApp(true);
+            qInfo() << __FUNCTION__ << __LINE__ << "启动3s超时监听";
+            delayTime->start(QThread::HighestPriority);
+            qInfo() << __FUNCTION__ << __LINE__ << "正在释放截图录屏全局事件X11相关资源...";
+            m_pScreenCaptureEvent->releaseRes();
+            //m_pScreenCaptureEvent->terminate();
+            qInfo() << __FUNCTION__ << __LINE__ << "全局事件监听线程正在等待释放x11相关资源...";
+            m_pScreenCaptureEvent->wait();
+            qInfo() << __FUNCTION__ << __LINE__ << "已释放X11相关资源";
+            delete m_pScreenCaptureEvent;
+            m_pScreenCaptureEvent = nullptr;
+            qInfo() << __FUNCTION__ << __LINE__ << "截图录屏全局事件监听线程已退出！";
+            delayTime->setForceToExitApp(false);
+            delayTime->stop();
+            if (delayTime) {
+                delete delayTime;
+                delayTime = nullptr;
+            }
+        }
         //以前的流程没执行到此处，没暴露延迟500ms的问题，以前的无用代码
         QThread::currentThread()->msleep(500);
+        qInfo() << __FUNCTION__ << __LINE__ << "截图录屏相关资源已释放";
     }
 
     enum ShotMouseStatus {
@@ -541,11 +547,24 @@ public slots:
      */
     void exitScreenCuptureEvent();
     void showPreviewWidgetImage(QImage img);//显示预览窗口和图片
+
+    /**
+     * @brief 有些时候退出全局事件监听线程会卡住，此时强退截图录屏
+     */
+    void onExitScreenCapture();
 protected:
     bool eventFilter(QObject *object, QEvent *event) override;
     void keyPressEvent(QKeyEvent *event) override;
     void keyReleaseEvent(QKeyEvent *event) override;
     int getAction(QEvent *event);
+
+    /**
+     * @brief paintImage: 绘制图片
+     * @return 结果
+     * 将背景图进行裁剪，并将编辑的内容绘制到图片上
+     */
+    QPixmap paintImage();
+
     void paintEvent(QPaintEvent *event) override;
     void resizeBottom(QMouseEvent *event);
     void resizeLeft(QMouseEvent *event);
@@ -681,6 +700,10 @@ protected:
      * @brief 启动截图录屏时检测是否是锁屏状态
      */
     void checkIsLockScreen();
+
+    void initDynamicLibPath();
+    QString libPath(const QString &strlib);
+
 private:
 //    QList<WindowRect> windowRects;
     /**
@@ -697,6 +720,10 @@ private:
     RecordProcess recordProcess;
     voiceVolumeWatcher *m_pVoiceVolumeWatcher = nullptr;
     CameraWatcher *m_pCameraWatcher = nullptr;
+    /**
+     * @brief 摄像头设备监听器
+     */
+    DevNumMonitor *m_devnumMonitor = nullptr;
     ScreenGrabber m_screenGrabber;
 //    VoiceRecordProcess voiceRecordProcess;
 //    WindowRect rootWindowRect;
@@ -955,6 +982,9 @@ private:
      *   1.2.如果需将1920*1080上的点换算到此屏幕应该除以m_pixelRatio
      */
     qreal m_pixelRatio = 1.0;
+    /**
+     * @brief 是否打开窗口特效；true:3d模式 false:2d模式
+     */
     bool m_hasComposite = true;
     bool m_initScreenShot;
     bool m_initScreenRecorder;
