@@ -1,46 +1,12 @@
-/*
+// Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
-* Copyright (C) 2019 ~ 2019 Deepin Technology Co., Ltd.
-
-*
-
-* Author:     wangcong <wangcong@uniontech.com>
-
-*
-
-* Maintainer: wangcong <wangcong@uniontech.com>
-
-*
-
-* This program is free software: you can redistribute it and/or modify
-
-* it under the terms of the GNU General Public License as published by
-
-* the Free Software Foundation, either version 3 of the License, or
-
-* any later version.
-
-*
-
-* This program is distributed in the hope that it will be useful,
-
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-
-* GNU General Public License for more details.
-
-*
-
-* You should have received a copy of the GNU General Public License
-
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-*/
 #include "pinscreenshots.h"
 #include "service/pinscreenshotsinterface.h"
 #include "service/dbuspinscreenshotsadaptor.h"
-#include "utils.h"
+#include "putils.h"
 
 #include <DWidget>
 #include <DLog>
@@ -74,8 +40,8 @@ int main(int argc, char *argv[])
         qDebug() << "Cant open a null file";
         return 0;
     }
-    Utils::isWaylandMode = isWaylandProtocol();
-    if (Utils::isWaylandMode) {
+    PUtils::isWaylandMode = isWaylandProtocol();
+    if (PUtils::isWaylandMode) {
         qputenv("QT_WAYLAND_SHELL_INTEGRATION", "kwayland-shell");
     }
 
