@@ -1,29 +1,14 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     Hou Lei <houlei@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "record_process.h"
 #include "utils/configsettings.h"
 #include "utils.h"
 #include "utils/audioutils.h"
 #include "gstrecord/gstinterface.h"
+#include "utils/eventlogutils.h"
 #ifdef KF5_WAYLAND_FLAGE_ON
 #include "waylandrecord/avlibinterface.h"
 #endif
@@ -35,7 +20,8 @@
 #include <QtDBus>
 #include <QScreen>
 #include <QMetaType>
-
+#include <QClipboard>
+#include <QUrl>
 #include <dlfcn.h>
 #include <signal.h>
 
@@ -56,18 +42,13 @@ const int RecordProcess::RECORD_FRAMERATE_30 = 30;
 
 RecordProcess::RecordProcess(QObject *parent) : QObject(parent)
 {
+    qDebug() << "录屏控制类初始化！";
     settings = ConfigSettings::instance();
     m_framerate = RECORD_FRAMERATE_24;
 
     saveTempDir = QStandardPaths::standardLocations(QStandardPaths::TempLocation).first();
-    saveDir = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first() + QDir::separator() + "Screen Recordings" + QDir::separator();
     displayNumber = QString(std::getenv("DISPLAY"));
 
-    if ((!QDir(saveDir).exists() && QDir().mkdir(saveDir) == false) ||  // 文件不存在，且创建失败
-            (QDir(saveDir).exists() && !QFileInfo(saveDir).isWritable())) {  // 文件存在，且不能写
-        saveDir = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first();
-    }
-    qDebug() << saveDir;
     if (settings->value("recordConfig", "lossless_recording").toString() == "") {
         settings->setValue("recordConfig", "lossless_recording", false);
     }
@@ -408,7 +389,55 @@ void RecordProcess::initProcess()
 
 
 }
+void RecordProcess::getScreenRecordSavePath()
+{
+    if (settings->value("recordConfig", "savepath").toString() == "") {
+        qWarning() << "配置文件中录屏保存路径为空,采用默认路径";
+        saveDir = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first() + QDir::separator() + "Screen Recordings" + QDir::separator();
+    } else {
+        int t_saveIndex = ConfigSettings::instance()->value("recordConfig", "save_op_record").toInt();
+        switch (t_saveIndex) {
+        case 0: {
+            //保存到桌面
+            saveDir = settings->value("recordConfig", "savepath").toString() + QDir::separator();
+            break;
+        }
+        default:
+            //保存到视频目录中的Screen Recordings目录
+            saveDir = settings->value("recordConfig", "savepath").toString() + QDir::separator() + "Screen Recordings" + QDir::separator();
+            break;
+        }
+    }
+    if ((!QDir(saveDir).exists() && QDir().mkdir(saveDir) == false) ||  // 文件不存在，且创建失败
+            (QDir(saveDir).exists() && !QFileInfo(saveDir).isWritable())) {  // 文件存在，且不能写
+        saveDir = QStandardPaths::standardLocations(QStandardPaths::MoviesLocation).first();
+    }
+    qInfo() << "录屏保存目录: " << saveDir;
+}
 
+void RecordProcess::save2Clipboard(QString file)
+{
+    //录屏文件保存到剪切板
+    QClipboard *cb = qApp->clipboard();
+    // Ownership of the new data is transferred to the clipboard.
+    QMimeData *newMimeData = new QMimeData();
+
+    QByteArray gnomeFormat = QByteArray("copy\n");
+    QString text;
+    QList<QUrl> dataUrls;
+
+    dataUrls << QUrl::fromLocalFile(file);
+    gnomeFormat.append(QUrl::fromLocalFile(file).toEncoded()).append("\n");
+
+    newMimeData->setText(text.endsWith('\n') ? text.left(text.length() - 1) : text);
+    newMimeData->setUrls(dataUrls);
+
+    gnomeFormat.remove(gnomeFormat.length() - 1, 1);
+
+    newMimeData->setData("x-special/gnome-copied-files", gnomeFormat);
+
+    cb->setMimeData(newMimeData, QClipboard::Clipboard);
+}
 //wayland录制视频
 void RecordProcess::waylandRecord()
 {
@@ -547,8 +576,9 @@ void RecordProcess::setSystemAudio(const bool status)
 //开始录屏
 void RecordProcess::startRecord()
 {
+    getScreenRecordSavePath();
     //使用QtConcurrent::run受cpu核心线程数的影响，线程池默认大小为CPU核心线程数大小，由于程序中通过此方法启动的线程数超出4个，故再次设置线程池大小
-    QThreadPool::globalInstance()->setMaxThreadCount(QThreadPool::globalInstance()->maxThreadCount() > 6 ? QThreadPool::globalInstance()->maxThreadCount() : 6);
+    QThreadPool::globalInstance()->setMaxThreadCount(QThreadPool::globalInstance()->maxThreadCount() > 6 ? QThreadPool::globalInstance()->maxThreadCount() : 8);
     m_framerate = settings->value("recordConfig", "mkv_framerate").toString().toInt();
     qDebug() << "m_selectedMic: " << m_selectedMic;
     qDebug() << "m_selectedSystemAudio: " << m_selectedSystemAudio;
@@ -574,9 +604,8 @@ void RecordProcess::startRecord()
             if (Utils::isTabletEnvironment) {
                 return;
             }
-        }
-        //wayland下的录屏
-        else {
+        } else {
+            //wayland下的录屏
             if (recordType != RECORD_TYPE_GIF) {
                 if (settings->value("recordConfig", "lossless_recording").toBool()) {
                     recordType = RECORD_TYPE_MKV;
@@ -587,6 +616,15 @@ void RecordProcess::startRecord()
             waylandRecord();
         }
     }
+
+    QJsonObject obj{
+        {"tid", EventLogUtils::StartRecording},
+        {"version", QCoreApplication::applicationVersion()},
+        {"type", recordType == RECORD_TYPE_GIF ? "gif" :
+                                                 (settings->value("recordConfig", "lossless_recording").toBool() || recordType == RECORD_TYPE_MKV ? "mkv" : "mp4")}
+    };
+    EventLogUtils::get().writeLogs(obj);
+
     if (Utils::isSysHighVersion1040() == false) {
         return;
     }
@@ -616,6 +654,13 @@ void RecordProcess::emitRecording()
 
 void RecordProcess::stopRecord()
 {
+//    QJsonObject obj{
+//        {"tid", EventLogUtils::EndRecording},
+//        {"version", QCoreApplication::applicationVersion()},
+//        {"type", recordType == RECORD_TYPE_GIF ? "gif" : (recordType == RECORD_TYPE_MKV ? "mkv" : "mp4")}
+//    };
+//    EventLogUtils::get().writeLogs(obj);
+
     if (Utils::isSysHighVersion1040() == true) {
         qDebug() << "Pause the screen recording timer!";
 
@@ -667,9 +712,11 @@ void RecordProcess::exitRecord(QString newSavePath)
 
         QStringList actions;
         actions << "_open" << tr("View");
-
+        actions << "_open1" << tr("Open Folder");
         QVariantMap hints;
         hints["x-deepin-action-_open"] = QString("xdg-open,%1").arg(newSavePath);
+        QString savepathcommand = QString("dde-file-manager,--show-item,%1").arg(newSavePath);
+        hints["x-deepin-action-_open1"] = savepathcommand;
         int timeout = -1;
         unsigned int id = 0;
 
@@ -687,7 +734,8 @@ void RecordProcess::exitRecord(QString newSavePath)
     if (recordType == RECORD_TYPE_GIF) {
         QFile::remove(savePath);
     }
-    qDebug() << "savePath: " << newSavePath;
+    //保存到剪切板
+    save2Clipboard(newSavePath);
     if (Utils::isWaylandMode) {
 #ifdef KF5_WAYLAND_FLAGE_ON
         avlibInterface::unloadFunctions();
