@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
- *
- * Author:     He MingYang <hemingyang@uniontech.com>
- *
- * Maintainer: Liu Zheng <liuzheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "utils.h"
 #include "constant.h"
@@ -209,12 +193,26 @@ void Utils::cancelInputEvent1(const int wid, const short x, const short y, const
 // 判断系统是否是大于1040, 大于1040才显示录制时长功能。
 bool Utils::isSysHighVersion1040()
 {
-    const int version1040 = 1040;
     if (DSysInfo::isDeepin()) {
         bool correct = false;
-        int version = DSysInfo::minorVersion().toInt(&correct);
-        if (correct && (version >= version1040)) {
-            return true;
+        QString sysVersion = DSysInfo::minorVersion();
+        float version = sysVersion.toFloat(&correct);
+        qDebug() << "System Version:" << sysVersion << correct;
+        if(DSysInfo::UosProfessional == DSysInfo::uosEditionType() || DSysInfo::UosEducation == DSysInfo::uosEditionType()) {
+            const float versionProfessional = 1040;
+            if (correct && (version >= versionProfessional)) {
+                return true;
+            }
+        } else if(DSysInfo::UosHome == DSysInfo::uosEditionType()) {
+            const float versionHome = 21.3f;
+            if (correct && (version >= versionHome)) {
+                return true;
+            }
+        } else if(DSysInfo::UosCommunity == DSysInfo::uosEditionType()) {
+            const float versionCommunity = 20.6f;
+            if (correct && (version >= versionCommunity)) {
+                return true;
+            }
         }
     }
     return false;
@@ -277,6 +275,11 @@ void Utils::getAllWindowInfo(const quint32 winId, const int width, const int hei
             //window:后面代码有使用
             //window->deleteLater();
             //修改部分窗口显示不全，截图框识别问题
+            qDebug()  << "\n窗口名称: >>>> " <<window->wmClass()
+                      << "\nx: " <<  window->frameGeometry().x()
+                      << "\ny: " <<  window->frameGeometry().y()
+                      << "\nwidth: " <<  window->frameGeometry().width()
+                      << "\nheight: " <<  window->frameGeometry().height()   ;
             //x坐标小于0时
             if (window->frameGeometry().x() < 0) {
                 if (window->frameGeometry().y() < 0) {
@@ -417,3 +420,74 @@ void Utils::notSupportWarn()
     warnDlg.addButton(tr("Exit"));
     warnDlg.exec();
 }
+
+//传入屏幕上理论未经缩放的点，获取缩放后实际的点
+QPoint Utils::getPosWithScreen(QPoint pos)
+{
+    QPoint dpos;
+    QList<ScreenInfo> screensInfo;
+    //获取所有实际屏幕的信息
+    screensInfo = getScreensInfo();
+    qreal pixelRatio = qApp->primaryScreen()->devicePixelRatio();
+
+    for (int i = 0; i < screensInfo.size(); i++) {
+        //判断当前点在哪块屏幕上
+        if (pos.x() > screensInfo[i].x && pos.x() < screensInfo[i].x + screensInfo[i].width &&
+                pos.y() > screensInfo[i].y && pos.y() < screensInfo[i].y + screensInfo[i].height) {
+
+            qInfo() << "screenInfo: " << screensInfo[i].toString();
+            dpos.setX(static_cast<int>((pos.x() - screensInfo[i].x) / pixelRatio + screensInfo[i].x));
+            dpos.setY(static_cast<int>((pos.y() - screensInfo[i].y) / pixelRatio) + + screensInfo[i].y);
+        }
+    }
+    return dpos;
+}
+
+//传入屏幕上已经缩放后的点，获取理论上实际的点
+QPoint Utils::getPosWithScreenP(QPoint pos)
+{
+    QPoint dpos;
+    QList<ScreenInfo> screensInfo;
+    //获取所有实际屏幕的信息
+    screensInfo = getScreensInfo();
+    qreal pixelRatio = qApp->primaryScreen()->devicePixelRatio();
+    for (int i = 0; i < screensInfo.size(); i++) {
+        //判断当前点在哪块屏幕上
+        if (pos.x() > screensInfo[i].x && pos.x() < screensInfo[i].x + screensInfo[i].width &&
+                pos.y() > screensInfo[i].y && pos.y() < screensInfo[i].y + screensInfo[i].height) {
+
+            dpos.setX(static_cast<int>((pos.x() - screensInfo[i].x)*pixelRatio + screensInfo[i].x));
+            dpos.setY(static_cast<int>((pos.y() - screensInfo[i].y)*pixelRatio + screensInfo[i].y));
+        }
+    }
+
+    return dpos;
+}
+
+QList<Utils::ScreenInfo> Utils::getScreensInfo()
+{
+    //获取所有实际屏幕的信息
+    QList<QScreen *> screenList = qApp->screens();
+    qreal pixelRatio = qApp->primaryScreen()->devicePixelRatio();
+    QList<ScreenInfo> screensInfo;
+
+    /**
+     * 例如：显示器实际屏幕参数为1920*1080记为 t1，调整缩放比例为1.25记为 p,那么此时显示器显示的屏幕大小将变为1536*864记为 t2，
+     * 那么此时在 t2的点要变成t1上的点，需要 t2*p = t1,在多屏的情况且需要考虑究竟在那个屏幕上
+     */
+    //将实际屏幕信息根据缩放比列转化为理论上屏幕信息
+    int hTotal = 0;
+    for (auto it = screenList.constBegin(); it != screenList.constEnd(); ++it) {
+        QRect rect = (*it)->geometry();
+        //qDebug() << (*it)->name() << rect;
+        ScreenInfo screenInfo;
+        screenInfo.x = rect.x(); //屏幕的起始x坐标始终是正确的，不管是否经过缩放
+        screenInfo.y = rect.y(); //屏幕的起始y坐标始终是正确的，不管是否经过缩放
+        screenInfo.height =  static_cast<int>(rect.height() * pixelRatio);
+        screenInfo.width = static_cast<int>(rect.width() * pixelRatio);
+        screenInfo.name = (*it)->name();
+        hTotal += screenInfo.height;
+        screensInfo.append(screenInfo);
+    }
+    return screensInfo;
+}
