@@ -20,7 +20,7 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"/>
+        <translation>Tallennus</translation>
     </message>
 </context>
 <context>
@@ -96,10 +96,6 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Screenshot</source>
         <translation>Ruudunkaappaus</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>Ruudunkaappaus on tallennettu albumiin</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>Kaappaus epäonnistui.</translation>
@@ -112,6 +108,10 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Pin Screenshots</source>
         <translation>Kiinnitä kaappaukset</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Avaa kansio</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Record</source>
         <translation>Tallenna</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Avaa kansio</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <source>Pin screenshots</source>
         <translation>Kiinnitä kuvakaappaukset</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation>Aloita OCR</translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Aloita vierivä kaappaus</translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -548,11 +560,15 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
     </message>
     <message>
         <source>webm</source>
-        <translation type="unfinished"/>
+        <translation>webm</translation>
     </message>
     <message>
         <source>ogg</source>
-        <translation type="unfinished"/>
+        <translation>ogg</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Videot</translation>
     </message>
 </context>
 <context>
