@@ -20,7 +20,7 @@ ou pressione novamente o atalho para parar de gravar</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation type="unfinished"/>
+        <translation>Gravação</translation>
     </message>
 </context>
 <context>
@@ -96,10 +96,6 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Screenshot</source>
         <translation>Captura de ecrã</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>A captura de ecrã foi guardada no álbum</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>A captura de ecrã falhou.</translation>
@@ -112,6 +108,10 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Pin Screenshots</source>
         <translation>Afixar capturas de ecrã</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Abrir pasta</translation>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Record</source>
         <translation>Gravar</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation>Abrir pasta</translation>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <source>Pin screenshots</source>
         <translation>Afixar capturas de ecrã</translation>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation>Iniciar OCR</translation>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation>Iniciar scrollshot</translation>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -548,11 +560,15 @@ ou pressione novamente o atalho para parar de gravar</translation>
     </message>
     <message>
         <source>webm</source>
-        <translation type="unfinished"/>
+        <translation>webm</translation>
     </message>
     <message>
         <source>ogg</source>
-        <translation type="unfinished"/>
+        <translation>ogg</translation>
+    </message>
+    <message>
+        <source>Videos</source>
+        <translation>Vídeos</translation>
     </message>
 </context>
 <context>
