@@ -96,10 +96,6 @@ or press the shortcut again to stop recording</source>
         <source>Screenshot</source>
         <translation>Усликавање</translation>
     </message>
-    <message>
-        <source>The screenshot has been saved in the album</source>
-        <translation>Слика екрана је сачувана у албуму</translation>
-    </message>
     <message>
         <source>Screenshot failed.</source>
         <translation>Неуспешно усликавање.</translation>
@@ -112,6 +108,10 @@ or press the shortcut again to stop recording</source>
         <source>Pin Screenshots</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuController</name>
@@ -153,6 +153,10 @@ or press the shortcut again to stop recording</source>
         <source>Record</source>
         <translation>Снимање</translation>
     </message>
+    <message>
+        <source>Open Folder</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>Screenshot</name>
@@ -357,6 +361,14 @@ or press the shortcut again to stop recording</source>
         <source>Pin screenshots</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Start OCR</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Start scrollshot</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ShotStartPlugin</name>
@@ -554,6 +566,10 @@ or press the shortcut again to stop recording</source>
         <source>ogg</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Videos</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
